.. pynrc documentation master file, created by
   sphinx-quickstart on Mon Oct  9 11:42:06 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyNRC's documentation!
=================================

.. automodule:: pynrc
    :members:
    

.. toctree::
   :caption: Getting Started
   :maxdepth: 1
   
   readme.rst
   installation.rst
   install_clean.rst

.. toctree::
   :caption: User Guides
   :maxdepth: 1

   tutorials/Basic_Usage.ipynb   
   tutorials/Ramp_Optimization_Examples.ipynb
   tutorials/Coronagraph_Basics.ipynb
   tutorials/Coronagraph_Wedges.ipynb
   
.. toctree::
   :caption: Reference Info
   :maxdepth: 1
   
   api_new.rst
   change_log.rst
   license.rst
   contributing.rst
   


License & Attribution
---------------------

pyNRC is free software made available under the MIT License. For details
see :ref:`LICENSE <license>`.

.. attention:: Citing pyNRC

    If you make use of pyNRC in your work, please cite the following paper: 
    `Leisenring et al. 2018, "pyNRC: A NIRCam ETC and Simulation Toolset"`
    (in prep).

